==> league-shop-base-1.0.55.tar.gz: league-shop-base-1.0.55/lsb/managers.py <==
from typing import TYPE_CHECKING

from django.db import models
from django.db.models import ExpressionWrapper
from django.db.models import Q
from django.utils import timezone

if TYPE_CHECKING:
    # prevent cyclic imports
    from lsb.models import Product


class ProductQuerySet(models.QuerySet["Product"]):
    def valid(self):
        return self.filter(
            is_purchased=False,
            is_banned=False,
            is_auth_error=False,
            disabled_until__lt=timezone.now(),
        )

    def with_is_disabled(self):
        return self.annotate(
            is_disabled=ExpressionWrapper(
                Q(disabled_until__gt=timezone.now()),
                output_field=models.BooleanField(),
            )
        )

    def with_is_old_stock(self, threshold):
        return self.annotate(
            is_old_stock=ExpressionWrapper(
                Q(date_last_played__lte=threshold),
                output_field=models.BooleanField(),
            )
        )

    def with_is_ranked(self):
        return self.annotate(
            is_ranked=ExpressionWrapper(
                ~Q(rank="UNRANKED"),
                output_field=models.BooleanField(),
            )
        )


class ProductManager(models.Manager["Product"]):
    def get_queryset(self):
        return ProductQuerySet(self.model, using=self._db)

    def valid(self):
        return self.get_queryset().valid()

    def with_is_disabled(self):
        return self.get_queryset().with_is_disabled()

    def with_is_old_stock(self, threshold):
        return self.get_queryset().with_is_old_stock(threshold)

    def with_is_ranked(self):
        return self.get_queryset().with_is_ranked()

==> league-shop-base-1.0.59.tar.gz: league-shop-base-1.0.59/lsb/managers.py <==
from typing import TypeVar

from django.db import models
from django.db.models import ExpressionWrapper
from django.db.models import Q
from django.utils import timezone

import lsb.models

T = TypeVar("T")


class ProductQuerySet(models.QuerySet[T]):
    def valid(self):
        return self.filter(
            is_purchased=False,
            is_banned=False,
            is_auth_error=False,
            disabled_until__lt=timezone.now(),
        )

    def with_is_disabled(self):
        return self.annotate(
            is_disabled=ExpressionWrapper(
                Q(disabled_until__gt=timezone.now()),
                output_field=models.BooleanField(),
            )
        )

    def with_is_old_stock(self, threshold):
        return self.annotate(
            is_old_stock=ExpressionWrapper(
                Q(date_last_played__lte=threshold),
                output_field=models.BooleanField(),
            )
        )

    def with_is_ranked(self):
        return self.annotate(
            is_ranked=ExpressionWrapper(
                ~Q(rank="UNRANKED"),
                output_field=models.BooleanField(),
            )
        )


class ProductManager(models.Manager[T]):
    def get_queryset(self) -> ProductQuerySet[T]:
        return ProductQuerySet(self.model, using=self._db)

    def valid(self):
        return self.get_queryset().valid()

    def with_is_disabled(self):
        return self.get_queryset().with_is_disabled()

    def with_is_old_stock(self, threshold):
        return self.get_queryset().with_is_old_stock(threshold)

    def with_is_ranked(self):
        return self.get_queryset().with_is_ranked()


class ChampionManager(models.Manager[T]):
    def get_or_create_by_id(self, id):
        return self.get_or_create(id=id, defaults={"name": str(id)})


class SkinManager(models.Manager[T]):
    def get_or_create_by_id(self, id):
        champion = int(id / 1000)  # remove last 3 digits
        champion, _ = lsb.models.Champion.objects.get_or_create_by_id(champion)
        return self.get_or_create(
            id=id,
            defaults={
                "champion": champion,
                "name": str(id),
                "tier": "UNKNOWN",
            },
        )
